@@ -17,13 +17,17 @@ Browse the API:
    dev
 
 """
-__version__ = "0.5.0"
+
+__version__ = "0.9.2"
+
+import warnings
+
 from lndb_setup import settings  # noqa
 from lndb_setup._migrate import check_migrate as _check_migrate
 
 from . import _check_versions  # executes checks during import
 
-if settings.instance.storage_dir is None:
+if settings.instance.storage_root is None:
     raise RuntimeError("Please run `lndb init` to configure an instance.")
 _check_migrate(usettings=settings.user, isettings=settings.instance)
 
