@@ -15,17 +15,22 @@ def test_create_to_load():
     # create unnecessary tables
     import lamindb as ln
 
-    ln.db.insert.dobject_from_jupynb(
-        name="test_file",
-        suffix=".csv",
-        jupynb_id="83jf",
-        jupynb_v="1",
-        jupynb_name="test",
-        dobject_id="testid",
-        size=1.2,
+    dobject = ln.schema.core.dobject(
+        id="testid", name="test_file", suffix=".csv", size=1.2
     )
+    jupynb = ln.schema.core.jupynb(id="83jf", v="1", name="test")
+    ln.db.insert.jupynb(**jupynb.dict())
+    dtransform = ln.schema.core.dtransform(jupynb_id=jupynb.id, jupynb_v=jupynb)
+
+    ln.db.insert.dtransform(**dtransform.dict())
+    ln.db.insert.dobject_from_dtransform(dobject=dobject, dtransform_id=dtransform.id)
+
     for entity in ln.schema.list_entities():
-        getattr(ln.db.query, entity)().df()
+        getattr(ln.db.select, entity)().df()
+
+    ln.schema._core.get_db_metadata_as_dict()
+    table_object = ln.schema._core.get_table_object("dobject")
+    ln.schema._core.get_table_metadata_as_dict(table_object)
 
     (Path(storage) / "mydata-test-db.lndb").unlink()
     # Note that this merely removes database file but doesn't clean out the instance_settings file!  # noqa
