@@ -1,6 +1,7 @@
 from pathlib import Path
 
 from lamindb.dev._core import get_name_suffix_from_filepath
+from lamindb.dev.db._staged import compute_checksum
 
 
 def test_get_name_suffix_from_filepath():
@@ -16,3 +17,15 @@ def test_get_name_suffix_from_filepath():
     for path, name, suffix in dataset:
         filepath = Path(path)
         assert name, suffix == get_name_suffix_from_filepath(filepath)
+
+
+def test_compute_checksum():
+    dataset = [
+        ("file_1.txt", "a", "DMF1ucDxtqgxw5niaXcmYQ"),
+    ]
+    for path, content, checksum in dataset:
+        filepath = Path(path)
+        with open(path, "w") as file:
+            file.write(content)
+        assert checksum == compute_checksum(filepath)
+        filepath.unlink()
